Package: HiBED
Type: Package
Title: HiBED
Version: 1.10.0
Authors@R: c(person("Ze", "Zhang", role = c("cre", "aut"),
            email = "ze.zhang.gr@dartmouth.edu", comment=c(ORCID="0000-0001-9854-5823")),
            person(c("Lucas", "A."), "Salas", role = c("aut"),
            email = "lucas.a.salas.diaz@dartmouth.edu"))
Description: Hierarchical deconvolution for extensive cell type resolution in the human brain 
             using DNA methylation. The HiBED deconvolution estimates proportions up to 7 cell 
             types (GABAergic neurons, glutamatergic neurons, astrocytes, microglial cells, 
			 oligodendrocytes, endothelial cells, and stromal cells) in bulk brain tissues. 
License: GPL-3
Encoding: UTF-8
LazyData: false
VignetteBuilder: knitr
biocViews: ExperimentData, Homo_sapiens_Data, Tissue, MicroarrayData,
        Genome, MethylationArrayData, PackageTypeData
RoxygenNote: 7.2.3
URL: https://github.com/SalasLab/HiBED
Imports: dplyr, FlowSorted.Blood.EPIC, tibble, FlowSorted.DLPFC.450k,
        minfi, utils, AnnotationHub, SummarizedExperiment
Suggests: knitr, rmarkdown, testthat,
        IlluminaHumanMethylation450kmanifest
BugReports: https://github.com/SalasLab/HiBED/issues.
git_url: https://git.bioconductor.org/packages/HiBED
git_branch: RELEASE_3_23
git_last_commit: 2bb65e4
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-05-05
NeedsCompilation: no
Packaged: 2026-05-05 15:25:31 UTC; biocbuild
Author: Ze Zhang [cre, aut] (ORCID: <https://orcid.org/0000-0001-9854-5823>),
  Lucas A. Salas [aut]
Maintainer: Ze Zhang <ze.zhang.gr@dartmouth.edu>
Depends: R (>= 3.5.0)
