# Generated by roxygen2: do not edit by hand

export(HiBED_deconvolution)
import(AnnotationHub)
import(FlowSorted.Blood.EPIC)
import(FlowSorted.DLPFC.450k)
import(SummarizedExperiment)
import(dplyr)
import(tibble)
importFrom(minfi,getBeta)
importFrom(minfi,preprocessRaw)
importFrom(utils,data)
